@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model-Itself
 #
-# This software is Copyright (c) 2016 by Dominique Dumont.
+# This software is Copyright (c) 2007-2016 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -128,19 +128,21 @@
         'description' => [
             element => "Specify the elements names of this configuration class.",
             include => "Include the element description of another class into this class.",
-            include_after => "insert the included elements after a specific element",
+            include_after => "insert the included elements after a specific element. "
+            . "By default, included elements are placed before all other elements.",
             include_backend => "Include the read/write specification of another class into this class.",
             class_description => "Explain the purpose of this configuration class. This description will be re-used to generate the documentation of your configuration class. You can use pod markup to format your description. See L<perlpod> for details.",
             read_config => "Specify the Perl class(es) and function(s) used to read configuration data. The specified function will be tried in sequence to get configuration data. ",
             write_config => "Specify the Perl class and function used to write configuration data.",
-            generated_by => "When set, this class was generated by some program. You should not edit it as your modification may be clobbered later on",
+            generated_by => "When set, this class was generated by some program. You should not edit "
+                ."this class as your modifications may be clobbered later on when the class is regenerated.",
             accept => "Specifies names of the elements this configuration class will accept as valid. "
                 ."The key of the hash is a regular expression that will be tested against 
            candidate parameters. When the parameter matches the regular expression, 
            a new parameter is created in the model using the description provided
-           in the value of this hash key. Note that the regexp must match the whole 
-           candidate parameter name. I.e. the specified regexp will be eval\'ed 
-           with a leading ^ and a trailing \$."
+           in the value of this hash key. Note that the regexp must match the whole name
+           of the potential parameter. I.e. the specified regexp will be eval\'ed 
+           with a leading C<^> and a trailing C<\$>."
         ],
     ],
 
@@ -364,6 +366,18 @@
                     rules  => [ IniFile => { level => 'normal', } ],
                 }
             },
+
+            'auto_delete' => {
+                type             => 'leaf',
+                value_type       => 'boolean',
+                level            => 'normal',
+                upstream_default => 0,
+                summary          => 'Delete empty configuration file',
+                description      => 'Delete configuration files when no information is left in there.'
+                . ' This may happen when data is removed by user. This is mostly useful when the '
+                . ' configuration of an application is made of several files.',
+            },
+
         ],
         description => [
             join_list_value => 'string to join list values before writing the entry in ini file. Usually " " or ", "',
