@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model-Itself
 #
-# This software is Copyright (c) 2016 by Dominique Dumont.
+# This software is Copyright (c) 2007-2016 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -53,16 +53,6 @@
           upstream_default => 'standard' ,
          },
 
-       'experience' 
-       => {
-           type => 'leaf',
-           value_type => 'enum', 
-           choice => [qw/master advanced beginner/] ,
-           upstream_default => 'beginner',
-           status => 'deprecated',
-           description => 'Used to categorize configuration elements in several "required skills". Use this feature if you need to hide a parameter to novice users',
-          },
-
        'level' 
        => {
            type => 'leaf',
@@ -86,43 +76,20 @@
           description => 'enter detailed help information regarding this element',
          },
 
-      # all but warped_node
-      'warp' 
-      => { type => 'warped_node' , # ?
-           level => 'hidden',
-           follow => { elt_type => '- type' } ,
-           rules  => [
-                      '$elt_type ne "node"' =>
-                      {
-                       level => 'normal',
-                       config_class_name => 'Itself::WarpValue',
-                      }
-                     ] ,
-           description => "change the properties (i.e. default value or its value_type) dynamically according to the value of another Value object locate elsewhere in the configuration tree. "
-         },
+      # all but node or warped_node
+      'warp' => {
+          type => 'warped_node',
+          level => 'hidden',
+          config_class_name => 'Itself::WarpValue',
+          warp => {
+              follow => { elt_type => '- type' },
+              rules  => [
+                  '$elt_type ne "node"' => { level => 'normal' }
+              ]
+          },
+          description => "change the properties (i.e. default value or its value_type) dynamically according to the value of another Value object located elsewhere in the configuration tree. "
+      },
 
-      'rules' => {
-                  type => 'hash',
-                  ordered => 1,
-                  level      => 'hidden' ,
-                  index_type => 'string',
-                  warp => {
-                           follow => '- type',
-                           'rules'
-                             => { 'warped_node' => {level => 'normal',}
-                                }
-                          },
-                  cargo => { type => 'warped_node',
-                             follow => '- type',
-                             'rules'
-                             => { 'warped_node' 
-                                  => {
-                                      config_class_name => 'Itself::WarpOnlyElement' ,
-                                     }
-                                }
-                           },
-                  description => "Each key of a hash is a boolean expression using variables declared in the 'follow' parameters. The value of the hash specifies the effects on the node",
-                 },
       # hash or list
       'index_type' 
       => { type => 'leaf',
@@ -140,19 +107,20 @@
            description => 'Specify the type of allowed index for the hash. "String" means no restriction.',
          },
 
-      'cargo' 
-      => { type => 'warped_node',
-           level => 'hidden',
-           follow => { 't' => '- type' },
-           'rules' => [ '$t eq "list" or $t eq "hash"' 
-                        => {
-                            level => 'normal',
-                            config_class_name => 'Itself::CargoElement',
-                           },
-                      ],
-           description => 'Specify the properties of the configuration element configuration in this hash or list',
-         },
-
-     ],
+      'cargo' => {
+          type => 'warped_node',
+          level => 'hidden',
+          warp => {
+              follow => { 't' => '- type' },
+              'rules' => [
+                  '$t eq "list" or $t eq "hash"' => {
+                      level => 'normal',
+                      config_class_name => 'Itself::CargoElement',
+                  },
+              ],
+          },
+          description => 'Specify the properties of the configuration element configuration in this hash or list',
+      }
+  ],
  ],
 ];
