@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model-Itself
 #
-# This software is Copyright (c) 2016 by Dominique Dumont.
+# This software is Copyright (c) 2007-2016 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -35,18 +35,22 @@
                 type       => 'leaf',
                 level      => 'hidden',
                 value_type => 'enum',
+                choice => [
+                    qw/boolean enum integer reference
+                       number uniline string file dir/
+                ],
                 'warp'     => {
                     follow  => { 't' => '- type' },
                     'rules' => [
                         '$t eq "leaf"' => {
-                            choice => [
-                                qw/boolean enum integer reference
-                                  number uniline string file dir/
-                            ],
                             level     => 'normal',
                             mandatory => 1,
                         }
                     ]
+                },
+                help => {
+                    integer => 'positive or negative integer',
+                    uniline => 'string with no embedded newline',
                 }
             },
 
@@ -66,29 +70,6 @@
                 }
             },
 
-            # node element (may be within a hash or list)
-
-            # warped_node: warp parameter for warped_node. They must be
-            # warped out when type is not a warped_node
-            'follow' => {
-                type       => 'hash',
-                index_type => 'string',
-                level      => 'hidden',
-                'warp'     => {
-                    follow  => '- type',
-                    'rules' => { 'warped_node' => { level => 'normal', }, }
-                },
-                cargo => {
-                    type       => 'leaf',
-                    value_type => 'uniline'
-                },
-                description =>
-                  "Specifies the path to the value elements that drive the "
-                  . "change of this node. Each key of the has is a variable name used "
-                  . "in the 'rules' parameter. The value of the hash is a path in the "
-                  . "configuration tree",
-            },
-
             'morph' => {
                 type       => 'leaf',
                 level      => 'hidden',
@@ -135,17 +116,19 @@
 
             'computed_refer_to' => {
                 type   => 'warped_node',
-                follow => {
-                    t  => '- type',
-                    vt => '- value_type',
-                },
                 level      => 'hidden',
-                'rules'    => [
-                    '$t  eq "check_list" or $vt eq "reference"' => {
-                        level             => 'normal',
-                        config_class_name => 'Itself::ComputedValue',
+                warp => {
+                    follow => {
+                        t  => '- type',
+                        vt => '- value_type',
                     },
-                ],
+                    'rules'    => [
+                        '$t  eq "check_list" or $vt eq "reference"' => {
+                            level             => 'normal',
+                            config_class_name => 'Itself::ComputedValue',
+                        },
+                    ],
+                },
                 description =>
                   "points to an array or hash element in the configuration "
                   . "tree using a path computed with value from several other "
@@ -174,13 +157,15 @@
                 type       => 'warped_node',
                 level      => 'hidden',
 
-                follow  => { t => '- type', },
-                'rules' => [
-                    '$t  eq "leaf"' => {
-                        level             => 'normal',
-                        config_class_name => 'Itself::ComputedValue',
-                    },
-                ],
+                warp => {
+                    follow  => { t => '- type', },
+                    'rules' => [
+                        '$t  eq "leaf"' => {
+                            level             => 'normal',
+                            config_class_name => 'Itself::ComputedValue',
+                        },
+                    ],
+                },
                 description =>
                   "compute the default value according to a formula and value "
                   . "from other elements in the configuration tree.",
@@ -190,13 +175,15 @@
                 type       => 'warped_node',
                 level      => 'hidden',
 
-                follow  => { t => '- type', },
-                'rules' => [
-                    '$t  eq "leaf"' => {
-                        level             => 'normal',
-                        config_class_name => 'Itself::MigratedValue',
-                    },
-                ],
+                warp => {
+                    follow  => { t => '- type', },
+                    'rules' => [
+                        '$t  eq "leaf"' => {
+                            level             => 'normal',
+                            config_class_name => 'Itself::MigratedValue',
+                        },
+                    ],
+                },
                 description =>
                     "Specify an upgrade path from an old value and compute "
                   . "the value to store in the new element.",
